@@ -1,10 +1,9 @@
 """
 Evaluators for assessing task responses.
 """
+
 from __future__ import annotations
 
 from hud.evaluators.base import Evaluator
 
-__all__ = [
-    "Evaluator"
-]
+__all__ = ["Evaluator"]
