@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import enum
 from pathlib import Path
-from typing import Literal, TypeAlias
+from typing import Any, Literal, TypeAlias
 
 from pydantic import BaseModel
 
@@ -28,6 +28,9 @@ class CustomGym(BaseModel):
     # B. If string, then it is the uri of the docker image to use.
     #    The controller must already be installed in the image.
     image_or_build_context: str | Path
+    # host_config will be passed to the docker client when creating the environment.
+    # refer to official docker api documentation for available configs.
+    host_config: dict[str, Any] | None = None
 
 
 class EnvironmentStatus(str, enum.Enum):
@@ -48,7 +51,30 @@ class EnvironmentStatus(str, enum.Enum):
 
 
 # Available HUD gyms
-ServerGym: TypeAlias = Literal["qa", "hud-browser", "OSWorld-Ubuntu"]
+ServerGym: TypeAlias = Literal["qa", "hud-browser", "OSWorld-Ubuntu", "docker"]
 
 # Gyms can be either custom or server-side
 Gym: TypeAlias = CustomGym | ServerGym
+
+
+# Metadata keys for the environment.
+# partial: Whether the environment evaluator should give partial grades.
+# eval_model: The model to use for evaluation when running a VLM. Wraps langchain.
+# agent_name: The name of the agent that was used for running this task.
+ServerMetadataKeys: TypeAlias = Literal["partial", "eval_model", "agent_name"]
+MetadataKeys: TypeAlias = str | ServerMetadataKeys
+
+
+# Dictionary of sensitive data (only supported for hud-browser environments)
+# key: website name or page identifier
+# value: Dictionary of credentials for the sensitive data
+# Example:
+# {
+#     "google.com": {
+#         "google_username": "my_username",
+#         "google_password": "my_password"
+#     }
+# }
+# The agent only has access to the key of the credential, not the value. (i.e. google_username)
+# The value is only available to the environment. (i.e. my_username)
+SensitiveData: TypeAlias = dict[str, dict[str, str]]
